@@ -3,21 +3,30 @@ use warnings FATAL => 'recursion';
 
 package Daiku;
 use 5.008001;
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 use Daiku::Registry;
+use IPC::System::Simple ();
 
 sub import {
     my ($class) = @_;
     my $pkg = caller(0);
     no strict 'refs';
+    *{"${pkg}::desc"} = \&_desc;
     *{"${pkg}::task"} = \&_task;
     *{"${pkg}::file"} = \&_file;
     *{"${pkg}::rule"} = \&_rule;
+    *{"${pkg}::sh"}   = \&IPC::System::Simple::run;
     my $engine = Daiku::Registry->new();
     *{"${pkg}::engine"} = sub { $engine };
     *{"${pkg}::build"} = sub { $engine->build(@_) };
 }
 
+sub _desc($) {
+    my $desc = shift;
+
+    caller(0)->engine->temporary_desc($desc);
+}
+
 # task 'all' => ['a', 'b'];
 # task 'all' => ['a', 'b'] => sub { ... };
 sub _task($$;&) {
@@ -30,8 +39,14 @@ sub _task($$;&) {
         $args{deps} = shift @_;
         $args{deps} = [$args{deps}] if !ref $args{deps};
     }
+    my $caller = caller(0);
+    my $desc = $caller->engine->clear_temporary_desc;
+    if (defined $desc) {
+        $args{desc} = $desc;
+    }
+
     my $task = Daiku::Task->new( %args );
-    caller(0)->engine->register($task);
+    $caller->engine->register($task);
 }
 
 # file 'all' => ['a', 'b'];
@@ -76,6 +91,7 @@ Daiku - Make for Perl
     use Daiku;
     use autodie ':all';
 
+    desc 'do all tasks';
     task 'all' => 'foo';
     file 'foo' => 'foo.o' => sub {
         system "gcc -c foo foo.o";
@@ -94,6 +110,10 @@ Daiku is yet another build system for Perl5.
 
 =over 4
 
+=item C<< desc $desc:Str >>
+
+Description of following task.
+
 =item C<< task $name:Str, \@deps:ArrayRef[Str] >>
 
 =item C<< task $name:Str, \@deps:ArrayRef[Str], \&callback >>
