@@ -38,8 +38,9 @@ sub compile {
 
 sub write_file {
     my ($fname, $content) = @_;
-    open my $fh, '>', $fname or die;
-    print {$fh} $content;
+    open my $fh, '>', $fname or die "Cannot open file: $fname: $!";
+    print({$fh} $content) or die "Cannot write file: $fname";
+    close $fh or die "Cannot close file: $fname";
 }
 
 package t::Util::TmpDir;
